About
=====

This repository contains external type annotations (see `PEP 484 <https://www.python.org/dev/peps/pep-0484/>`_) for the `aiojobs <https://github.com/aio-libs/aiojobs>`_ library.

Installation
============

To use these stubs with mypy, you have to install the aiojobs-stubs package.

.. code-block:: python

  pip install aiojobs-stubs